@@ -1,13 +1,13 @@
-function dC(name) {
-	get_card_image(name);
+function dC(scryfallId) {
+	document.getElementById("card-image").src = "https://api.scryfall.com/cards/"+scryfallId+"?format=image";
 	document.getElementById("card-modal").style.display = "block";
 }
 
-function hC(name) {
+function hC(scryfallId) {
 	if (window.matchMedia("(hover: none)").matches) {
 		return
 	}
-	get_card_image(name);
+	document.getElementById("card-hover-image").src = "https://api.scryfall.com/cards/"+scryfallId+"?format=image";
 	document.getElementById("card-hover").style.display = "block";
 }
 
